pygeodesy.ecef.EcefFarrell21

Package pygeodesy :: Module ecef :: Class EcefFarrell21 |
[frames] | no frames]

# Class EcefFarrell21

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
               _EcefBase --+
                           |
                          EcefFarrell21

Conversion between geodetic and geocentric, Earth-Centered, Earth-Fixed (ECEF) coordinates based on Jay A. Farrell's Table 2.1, page 29.

Instance Methods
reverse(self, xyz, y=None, z=None, M=None, **lon00_name) Convert from geocentric `(x, y, z)` to geodetic `(lat, lon, height)` using Farrell's Table 2.1, page 29, aka the Heikkinen application of Ferrari's solution. |
Inherited from `_EcefBase`: `__eq__`, `__init__`, `forward`, `forward_`, `toStr` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_EcefBase`: `a`, `datum`, `ellipsoid`, `equatoradius`, `equatorialRadius`, `f`, `flattening`, `lon00` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### reverse (self, xyz, y=None, z=None, M=None, **lon00_name) |
Convert from geocentric `(x, y, z)` to geodetic `(lat, lon, height)` using Farrell's Table 2.1, page 29, aka the Heikkinen application of Ferrari's solution. Arguments: `xyz` - A geocentric (`Cartesian`, Ecef9Tuple) or `scalar` ECEF `x` coordinate (`meter`). `y` - ECEF `y` coordinate for `scalar` `xyz` and `z` (`meter`). `z` - ECEF `z` coordinate for `scalar` `xyz` and `y` (`meter`). `M` - Ignored, rotation matrix `M` not available. `lon00_name` - Optional `name=NN` (`str`) and optional keyword argument `lon00=INT0` (`degrees`), an arbitrary "polar" longitude returned if `x=0` and `y=0`, see property `lon00`. Returns: An Ecef9Tuple`(x, y, z, lat, lon, height, C, M, datum)` with geodetic coordinates `(lat, lon, height)` for the given geocentric ones `(x, y, z)`, case `C`, `M=None` always and `datum`. Raises: `EcefError` - Invalid `xyz` or `scalar` `x` or `y` and/or `z` not `scalar` for `scalar` `xyz` or `sqrt` domain or zero division error. Overrides: _EcefBase.reverse See Also: EcefFarrell22 and EcefVeness.